.. _interface-index:

===========================
Timeserie Interface
===========================

At the core of ``dynts`` stands the :class:`dynts.TimeSeries`, 
the interface class for Time Series. Every timeseries object
is an instance of this interface.


.. toctree::
   :maxdepth: 2

   interface
   creating
   design
